---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: true
---

# Events on a Vertical Screen

The event description is usually only one line.
When a screen is vertical however, they will be all trucated.

[@dml105] discussed this use-case in [Issue 625] and we found a solution.
Using **CSS** and **JavaScript** modifications, the Open Web Calendar can be modified to display all events on a vertical screen.
They can be made higher.

![]({{link.img}}/showcase/events-large-screen.png)

[@dml105]: https://github.com/dml105
[Issue 625]: https://github.com/niccokunzmann/open-web-calendar/issues/625
